function [ x, lambda ] = Potenzverfahren( A, x0, tol, maxit )
% [ x, lambda ] = Potenzverfahren( A, x0, tol, maxIt )
%   Pozentverfahren zur Approximation des betragsgroessten Eigenwerts von A
%   
%   Input:
%       A       Matrix dessen betragsgroesster EW gesucht ist
%       x0      Startvector
%       tol     Tolleranz der relativen Aenderung des gefundenen EW
%       maxIt   maximale Anzahl an Iterationen
%
%   Output:
%       x       Approximation an den Eigenvector
%       lambda  Array mit den Naeherungen an den gesuchten Eigenwert

%% Daten initialisieren
x = x0 / norm(x0); % EV 
lambda = zeros(maxit + 1, 1); % Array mit den Naeherungen an den gesuchten EW
y = A * x;
lambda(1) = x' * y;

%% Iteration
for j = 2 : maxit + 1
    mu = norm(y); % Norm des EV
    x = y / mu; % EV  normieren
    % y fuer den nachten Iterationsscchritt und fuer den Rayleigh
    % Quotienten
    y = A * x;
    % Rayleigh Quotient fuer den EW
    lambda(j) = x' * y;
    % Abbruchkriterium: relative Aenderung des EW
    if abs(lambda(j) - lambda(j - 1)) / lambda(j - 1) < tol
        break
    end
end

%% Ausgabe vorbereiten
lambda = lambda(1 : j);
end

