function [ x, lambda ] = inverse_Iteration( A, x0, tol, maxit )
% [ x, lambda ] = inverse_Iteration( A, x0, tol, maxIt )
%   inverse Iteration zur Approximation des betragskleinsten Eigenwerts von A
%   
%   Input:
%       A       Matrix dessen betragskleinster EW gesucht ist
%       x0      Startvektor
%       tol     Tolleranz der relativen Aenderung des gefundenen EW
%       maxIt   maximale Anzahl an Iterationen
%
%   Output:
%       x       Approximation an den Eigenvektor
%       lambda  Array mit den Naeherungen an den gesuchten Eigenwert

%% Daten initialisieren
x = x0 / norm(x0); % EV 
lambda = zeros(maxit + 1, 1); % Array mit den Naeherungen an den gesuchten EW
lambda(1) = x' * A * x;

%% Iteration
for j = 2 : maxit + 1
    y = A \ x;
    mu = norm(y); % Norm des EV
    x = y / mu; % EV normieren
    % Rayleigh Quotient fuer den EW
    lambda(j) = x' * A * x;
    % Abbruchkriterium: relative Aenderung des EW
    if abs(lambda(j) - lambda(j - 1)) / lambda(j - 1) < tol
        break
    end
end

%% Ausgabe vorbereiten
lambda = lambda(1 : j);
end

